
#include <e32base.h>
#include <oplerr.h>
#include <opx.h>
#include "OpxTls.h"
#include "OpxTdesC.h"
#include "OpxTDes.h"
#include "OpxTPtr.h"
#include "OpxRealFormat.h"
#include "OpxTLex.h"
#include "OpxTLexMark.h"

//-------------------------------------------------------------------- New OPX
EXPORT_C COpxTls* NewOpxL( OplAPI& aOplAPI )
	{
	COpxTls* tls = ((COpxTls*)Dll::Tls());
	if (tls==NULL)
		{
		// OPX DLL loading
		tls = COpxTls::NewLC( aOplAPI );
		(void)Dll::SetTls(tls);
		}
	return (COpxTls*)tls;
	}

//-------------------------------------------------------------------- Version
EXPORT_C TUint Version()
	{
	return KOpxVersion;
	}

//-------------------------------------------------------------- Check version
TBool COpxTls::CheckVersion( TInt aVersion )
	{
	if ((aVersion & 0xFF00) > (KOpxVersion & 0xFF00))
		return EFalse;
	else
		return ETrue;
	}

//------------------------------------------------------------------------ New
COpxTls* COpxTls::NewLC( OplAPI& aOplAPI )
	{
	COpxTls* This = new(ELeave) COpxTls( aOplAPI );
	CleanupStack::PushL( This );
	This->ConstructL();
	CleanupStack::Pop();
	return This;
	}

//------------------------------------------------------------------------ Run
void COpxTls::RunL( TInt aProcNum )
	{
	switch (aProcNum )
		{
	case ESocketOPXVersion:
		SocketOPXVersion();
		break;

	case ETDesCAt:
		COpxTDesC::At(iOplAPI);
		break;
	case ETDesCCompare:
		COpxTDesC::Compare(iOplAPI);
		break;
	case ETDesCCompareC:
		COpxTDesC::CompareC(iOplAPI);
		break;
	case ETDesCCompareF:
		COpxTDesC::CompareF(iOplAPI);
		break;
	case ETDesCCompareStr:
		COpxTDesC::CompareStr(iOplAPI);
		break;
	case ETDesCCompareStrC:
		COpxTDesC::CompareStrC(iOplAPI);
		break;
	case ETDesCCompareStrF:
		COpxTDesC::CompareStrF(iOplAPI);
		break;
	case ETDesCEQ:
		COpxTDesC::EQ(iOplAPI);
		break;
	case ETDesCEQStr:
		COpxTDesC::EQStr(iOplAPI);
		break;
	case ETDesCFind:
		COpxTDesC::Find(iOplAPI);
		break;
	case ETDesCFindC:
		COpxTDesC::FindC(iOplAPI);
		break;
	case ETDesCFindF:
		COpxTDesC::FindF(iOplAPI);
		break;
	case ETDesCFindStr:
		COpxTDesC::FindStr(iOplAPI);
		break;
	case ETDesCFindStrC:
		COpxTDesC::FindStrC(iOplAPI);
		break;
	case ETDesCFindStrF:
		COpxTDesC::FindStrF(iOplAPI);
		break;
	case ETDesCGE:
		COpxTDesC::GE(iOplAPI);
		break;
	case ETDesCGEStr:
		COpxTDesC::GEStr(iOplAPI);
		break;
	case ETDesCGT:
		COpxTDesC::GT(iOplAPI);
		break;
	case ETDesCGTStr:
		COpxTDesC::GTStr(iOplAPI);
		break;
	case ETDesCLE:
		COpxTDesC::LE(iOplAPI);
		break;
	case ETDesCLength:
		COpxTDesC::Length(iOplAPI);
		break;
	case ETDesCLEStr:
		COpxTDesC::LEStr(iOplAPI);
		break;
	case ETDesCLeft:
		COpxTDesC::LeftL(iOplAPI);
		break;
	case ETDesCLocate:
		COpxTDesC::Locate(iOplAPI);
		break;
	case ETDesCLocateF:
		COpxTDesC::LocateF(iOplAPI);
		break;
	case ETDesCLocateReverse:
		COpxTDesC::LocateReverse(iOplAPI);
		break;
	case ETDesCLocateReverseF:
		COpxTDesC::LocateReverseF(iOplAPI);
		break;
	case ETDesCLT:
		COpxTDesC::LT(iOplAPI);
		break;
	case ETDesCLTStr:
		COpxTDesC::LTStr(iOplAPI);
		break;
	case ETDesCMatch:
		COpxTDesC::Match(iOplAPI);
		break;
	case ETDesCMatchC:
		COpxTDesC::MatchC(iOplAPI);
		break;
	case ETDesCMatchF:
		COpxTDesC::MatchF(iOplAPI);
		break;
	case ETDesCMatchStr:
		COpxTDesC::MatchStr(iOplAPI);
		break;
	case ETDesCMatchStrC:
		COpxTDesC::MatchStrC(iOplAPI);
		break;
	case ETDesCMatchStrF:
		COpxTDesC::MatchStrF(iOplAPI);
		break;
	case ETDesCMid:
		COpxTDesC::MidL(iOplAPI);
		break;
	case ETDesCNE:
		COpxTDesC::NE(iOplAPI);
		break;
	case ETDesCNEStr:
		COpxTDesC::NEStr(iOplAPI);
		break;
	case ETDesCRight:
		COpxTDesC::RightL(iOplAPI);
		break;
	case ETDesCStr:
		COpxTDesC::StrL(iOplAPI);
		break;

	case ETDesAppend:
		COpxTDes::Append(iOplAPI);
		break;
	case ETDesAppendChar:
		COpxTDes::AppendChar(iOplAPI);
		break;
	case ETDesAppendFill:
		COpxTDes::AppendFill(iOplAPI);
		break;
	case ETDesAppendJustify:
		COpxTDes::AppendJustify(iOplAPI);
		break;
	case ETDesAppendJustifyStr:
		COpxTDes::AppendJustifyStr(iOplAPI);
		break;
	case ETDesAppendNum:
		COpxTDes::AppendNum(iOplAPI);
		break;
	case ETDesAppendNumFloat:
		COpxTDes::AppendNumFloat(iOplAPI);
		break;
	case ETDesAppendNumRadix:
		COpxTDes::AppendNumRadix(iOplAPI);
		break;
	case ETDesAppendNumRadixUC:
		COpxTDes::AppendNumRadixUC(iOplAPI);
		break;
	case ETDesAppendStr:
		COpxTDes::AppendStr(iOplAPI);
		break;
	case ETDesCapitalize:
		COpxTDes::Capitalize(iOplAPI);
		break;
	case ETDesCollate:
		COpxTDes::Collate(iOplAPI);
		break;
	case ETDesCopy:
		COpxTDes::Copy(iOplAPI);
		break;
	case ETDesCopyC:
		COpxTDes::CopyC(iOplAPI);
		break;
	case ETDesCopyCP:
		COpxTDes::CopyCP(iOplAPI);
		break;
	case ETDesCopyF:
		COpxTDes::CopyF(iOplAPI);
		break;
	case ETDesCopyLC:
		COpxTDes::CopyLC(iOplAPI);
		break;
	case ETDesCopyStr:
		COpxTDes::CopyStr(iOplAPI);
		break;
	case ETDesCopyStrC:
		COpxTDes::CopyStrC(iOplAPI);
		break;
	case ETDesCopyStrCP:
		COpxTDes::CopyStrCP(iOplAPI);
		break;
	case ETDesCopyStrF:
		COpxTDes::CopyStrF(iOplAPI);
		break;
	case ETDesCopyStrLC:
		COpxTDes::CopyStrLC(iOplAPI);
		break;
	case ETDesCopyStrUC:
		COpxTDes::CopyStrUC(iOplAPI);
		break;
	case ETDesCopyUC:
		COpxTDes::CopyUC(iOplAPI);
		break;
	case ETDesDelete:
		COpxTDes::Delete(iOplAPI);
		break;
	case ETDesFill:
		COpxTDes::Fill(iOplAPI);
		break;
	case ETDesFillLen:
		COpxTDes::FillLen(iOplAPI);
		break;
	case ETDesFillZ:
		COpxTDes::FillZ(iOplAPI);
		break;
	case ETDesFillZLen:
		COpxTDes::FillZLen(iOplAPI);
		break;
	case ETDesFold:
		COpxTDes::Fold(iOplAPI);
		break;
	case ETDesInsert:
		COpxTDes::Insert(iOplAPI);
		break;
	case ETDesInsertStr:
		COpxTDes::InsertStr(iOplAPI);
		break;
	case ETDesJustify:
		COpxTDes::Justify(iOplAPI);
		break;
	case ETDesJustifyStr:
		COpxTDes::JustifyStr(iOplAPI);
		break;
	case ETDesLowerCase:
		COpxTDes::LowerCase(iOplAPI);
		break;
	case ETDesMaxLength:
		COpxTDes::MaxLength(iOplAPI);
		break;
	case ETDesNum:
		COpxTDes::Num(iOplAPI);
		break;
	case ETDesNumFloat:
		COpxTDes::NumFloat(iOplAPI);
		break;
	case ETDesNumRadix:
		COpxTDes::NumRadix(iOplAPI);
		break;
	case ETDesNumRadixUC:
		COpxTDes::NumRadixUC(iOplAPI);
		break;
	case ETDesRepeat:
		COpxTDes::Repeat(iOplAPI);
		break;
	case ETDesRepeatStr:
		COpxTDes::RepeatStr(iOplAPI);
		break;
	case ETDesReplace:
		COpxTDes::Replace(iOplAPI);
		break;
	case ETDesReplaceStr:
		COpxTDes::ReplaceStr(iOplAPI);
		break;
	case ETDesSetLength:
		COpxTDes::SetLength(iOplAPI);
		break;
	case ETDesSetMax:
		COpxTDes::SetMax(iOplAPI);
		break;
	case ETDesSwap:
		COpxTDes::Swap(iOplAPI);
		break;
	case ETDesTrim:
		COpxTDes::Trim(iOplAPI);
		break;
	case ETDesTrimAll:
		COpxTDes::TrimAll(iOplAPI);
		break;
	case ETDesTrimLeft:
		COpxTDes::TrimLeft(iOplAPI);
		break;
	case ETDesTrimRight:
		COpxTDes::TrimRight(iOplAPI);
		break;
	case ETDesZero:
		COpxTDes::Zero(iOplAPI);
		break;
	case ETDesUpperCase:
		COpxTDes::UpperCase(iOplAPI);
		break;
	case ETDesZeroTerminate:
		COpxTDes::ZeroTerminate(iOplAPI);
		break;

	case ENewTPtr:
		COpxTPtr::NewTPtrL(iOplAPI);
		break;
	case EDeleteTPtr:
		COpxTPtr::DeleteTPtr(iOplAPI);
		break;
	case ETPtrSet:
		COpxTPtr::SetL(iOplAPI);
		break;

	case ENewAlloc:
		COpxTPtr::NewAllocL(iOplAPI);
		break;
	case EDeleteAlloc:
		COpxTPtr::DeleteAlloc(iOplAPI);
		break;

	case ENewTRealFormat:
		COpxTRealFormat::NewRealFormatL(iOplAPI);
		break;
	case EDeleteTRealFormat:
		COpxTRealFormat::DeleteRealFormat(iOplAPI);
		break;
	case ETRealFormatPlaces:
		COpxTRealFormat::Places(iOplAPI);
		break;
	case ETRealFormatPoint:
		COpxTRealFormat::Point(iOplAPI);
		break;
	case ETRealFormatSetPlaces:
		COpxTRealFormat::SetPlaces(iOplAPI);
		break;
	case ETRealFormatSetPoint:
		COpxTRealFormat::SetPoint(iOplAPI);
		break;
	case ETRealFormatSetTriad:
		COpxTRealFormat::SetTriad(iOplAPI);
		break;
	case ETRealFormatSetTriLen:
		COpxTRealFormat::SetTriLen(iOplAPI);
		break;
	case ETRealFormatSetType:
		COpxTRealFormat::SetType(iOplAPI);
		break;
	case ETRealFormatSetWidth:
		COpxTRealFormat::SetWidth(iOplAPI);
		break;
	case ETRealFormatTriad:
		COpxTRealFormat::Triad(iOplAPI);
		break;
	case ETRealFormatTriLen:
		COpxTRealFormat::TriLen(iOplAPI);
		break;
	case ETRealFormatType:
		COpxTRealFormat::Type(iOplAPI);
		break;
	case ETRealFormatWidth:
		COpxTRealFormat::Width(iOplAPI);
		break;

	case ENewLex:
		COpxTLex::NewLexL(iOplAPI);
		break;
	case ENewLex2:
		COpxTLex::NewLex2L(iOplAPI);
		break;
	case ENewLex3:
		COpxTLex::NewLex3L(iOplAPI);
		break;
	case ENewLex4:
		COpxTLex::NewLex4L(iOplAPI);
		break;
	case EDeleteLex:
		COpxTLex::DeleteLex(iOplAPI);
		break;
	case ELexAssign:
		COpxTLex::Assign(iOplAPI);
		break;
	case ELexAssignDes:
		COpxTLex::AssignDes(iOplAPI);
		break;
	case ELexAssignStr:
		COpxTLex::AssignStr(iOplAPI);
		break;
	case ELexEos:
		COpxTLex::Eos(iOplAPI);
		break;
	case ELexGet:
		COpxTLex::Get(iOplAPI);
		break;
	case ELexInc:
		COpxTLex::Inc(iOplAPI);
		break;
	case ELexMark:
		COpxTLex::Mark(iOplAPI);
		break;
	case ELexMarkedOffset:
		COpxTLex::MarkedOffset(iOplAPI);
		break;
	case ELexMarkedToken:
		COpxTLex::MarkedTokenL(iOplAPI);
		break;
	case ELexMarkedTokenStr:
		COpxTLex::MarkedTokenStrL(iOplAPI);
		break;
	case ELexNextToken:
		COpxTLex::NextTokenL(iOplAPI);
		break;
	case ELexNextTokenStr:
		COpxTLex::NextTokenStrL(iOplAPI);
		break;
	case ELexOffset:
		COpxTLex::Offset(iOplAPI);
		break;
	case ELexPeek:
		COpxTLex::Peek(iOplAPI);
		break;
	case ELexRemainder:
		COpxTLex::RemainderL(iOplAPI);
		break;
	case ELexRemainderStr:
		COpxTLex::RemainderStrL(iOplAPI);
		break;
	case ELexRemainderFromMark:
		COpxTLex::RemainderFromMarkL(iOplAPI);
		break;
	case ELexRemainderFromMarkStr:
		COpxTLex::RemainderFromMarkStrL(iOplAPI);
		break;
	case ELexSkipAndMark:
		COpxTLex::SkipAndMark(iOplAPI);
		break;
	case ELexSkipCharacters:
		COpxTLex::SkipCharacters(iOplAPI);
		break;
	case ELexSkipSpace:
		COpxTLex::SkipSpace(iOplAPI);
		break;
	case ELexSkipSpaceAndMark:
		COpxTLex::SkipSpaceAndMark(iOplAPI);
		break;
	case ELexTokenLength:
		COpxTLex::TokenLength(iOplAPI);
		break;
	case ELexUnGet:
		COpxTLex::UnGet(iOplAPI);
		break;
	case ELexUnGetToMark:
		COpxTLex::UnGetToMark(iOplAPI);
		break;
	case ELexVal:
		COpxTLex::Val(iOplAPI);
		break;
	case ELexValFloat:
		COpxTLex::ValFloat(iOplAPI);
		break;
	case ELexValRadix:
		COpxTLex::ValRadix(iOplAPI);
		break;
	case ELexValRadixLimit:
		COpxTLex::ValRadixLimit(iOplAPI);
		break;

	case ENewLexMark:
		COpxTLexMark::NewLexMarkL(iOplAPI);
		break;
	case EDeleteLexMark:
		COpxTLexMark::DeleteLexMark(iOplAPI);
		break;

	default:
		User::Leave(KOplErrOpxProcNotFound);
		}
	}

//---------------------------------------------------------------- Constructor
COpxTls::COpxTls( OplAPI& aOplAPI )
	: COpxBase( aOplAPI )
	{
	__DECLARE_NAME(_S("COpxTls"));
	}

//----------------------------------------------------------------- Destructor
COpxTls::~COpxTls()
	{
	Dll::FreeTls();
	}

//------------------------------------------------------------------ Construct
void COpxTls::ConstructL()
	{
	}

//---------------------------------------------------------- SocketOPX Version
void COpxTls::SocketOPXVersion()
	{
	iOplAPI.Push((TInt16)KOpxVersion);
	}

//------------------------------------------------------------ DLL entry point
GLDEF_C TInt E32Dll( TDllReason /* aReason */)
	{
	return (KErrNone);
	}


